        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 28 <strong>control</strong><br>0,1,2,3,4,6,7,9,13,15,18,19,20,21,22,25,28,31,32,33,36,37,39,43,44,47,48,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 23 <br>5,8,10,11,12,14,16,17,23,24,26,27,29,30,34,35,38,40,41,42,45,46,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 28 <strong>control</strong><br>0,1,2,3,4,6,7,9,13,15,18,19,20,21,22,25,28,31,32,33,36,37,39,43,44,47,48,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 23 <br>5,8,10,11,12,14,16,17,23,24,26,27,29,30,34,35,38,40,41,42,45,46,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 28 <strong>control</strong><br>0,1,2,3,4,6,7,9,13,15,18,19,20,21,22,25,28,31,32,33,36,37,39,43,44,47,48,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 23 <br>5,8,10,11,12,14,16,17,23,24,26,27,29,30,34,35,38,40,41,42,45,46,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 28 <strong>control</strong><br>0,1,2,3,4,6,7,9,13,15,18,19,20,21,22,25,28,31,32,33,36,37,39,43,44,47,48,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 23 <br>5,8,10,11,12,14,16,17,23,24,26,27,29,30,34,35,38,40,41,42,45,46,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 28 <strong>control</strong><br>0,1,2,3,4,6,7,9,13,15,18,19,20,21,22,25,28,31,32,33,36,37,39,43,44,47,48,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 23 <br>5,8,10,11,12,14,16,17,23,24,26,27,29,30,34,35,38,40,41,42,45,46,49';}
}
